import { useQuery, UseQueryResult } from 'react-query';
import { LocalizedString } from '@mt/i18n';
import { useEventQuery } from '@mt/utils';
import { useEffect } from 'react';

interface Attraction {
  id: string;
  name: LocalizedString;
  iconUrl: string;
}

export function useGetAttractionList(): UseQueryResult<Attraction[]> {
  const { data, isSuccess } = useEventQuery('/widgets/attraction-with-details-list/events', [
    'REFRESH_DATA',
  ]);

  const attractionListQuery = useQuery<Attraction[]>(
    ['getAttractionList'],
    async () =>
      await fetch('https://localhost:8443/widgets/attraction-with-details-list/data')
        .then((res) => res.json())
        .then(({ touristAttractions }) => touristAttractions),
    {
      refetchOnWindowFocus: false,
      refetchOnMount: false,
    }
  );

  useEffect(() => {
    if (isSuccess && data.length) {
      attractionListQuery.refetch();
    }
  }, [data, isSuccess]);

  return attractionListQuery;
}
